Package: topconfects
Title: Top Confident Effect Sizes
Version: 1.28.0
Authors@R: person("Paul", "Harrison", email = "paul.harrison@monash.edu", role = c("aut", "cre"), comment=c(ORCID="0000-0002-3980-268X"))
Description: Rank results by confident effect sizes, while maintaining
        False Discovery Rate and False Coverage-statement Rate control.
        Topconfects is an alternative presentation of TREAT results
        with improved usability, eliminating p-values and instead
        providing confidence bounds. The main application is
        differential gene expression analysis, providing genes ranked
        in order of confident log2 fold change, but it can be applied
        to any collection of effect sizes with associated standard
        errors.
Depends: R (>= 3.6.0)
Imports: methods, utils, stats, assertthat, ggplot2, scales, grid,
        grDevices
Suggests: limma, edgeR, statmod, DESeq2, ashr, NBPSeq, dplyr, testthat,
        reshape2, tidyr, readr, org.At.tair.db, AnnotationDbi, knitr,
        rmarkdown, BiocStyle
License: LGPL-2.1 | file LICENSE
URL: https://github.com/pfh/topconfects
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
BugReports: https://github.com/pfh/topconfects/issues
biocViews: GeneExpression, DifferentialExpression, Transcriptomics,
        RNASeq, mRNAMicroarray, Regression, MultipleComparison
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:49:28 UTC
RemoteUrl: https://github.com/bioc/topconfects
RemoteRef: RELEASE_3_23
RemoteSha: f68dfcaf7293563e3b002f0fc699367712a96c8c
NeedsCompilation: no
Packaged: 2026-05-04 09:02:51 UTC; root
Author: Paul Harrison [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3980-268X>)
Maintainer: Paul Harrison <paul.harrison@monash.edu>
Built: R 4.6.0; ; 2026-05-04 09:20:15 UTC; unix
