# Generated by roxygen2: do not edit by hand

export(confects_plot)
export(confects_plot_me)
export(confects_plot_me2)
export(deseq2_confects)
export(edger_confects)
export(limma_confects)
export(nest_confects)
export(normal_confects)
export(rank_rank_plot)
import(methods)
import(stats)
import(utils)
importFrom(assertthat,assert_that)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_discrete)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_size)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(grDevices,colorRampPalette)
importFrom(grid,unit)
