# Topconfects 

TOP results by CONfident efFECT Size. Topconfects is intended for RNA-seq or microarray Differntial Expression analysis and similar, where we are interested in placing confidence bounds on many effect sizes--one per gene--from few samples.

Topconfects is now in Bioconductor. The github repository is for bleeding-edge development only.

* [Topconfects in Bioconductor, release version](https://bioconductor.org/packages/topconfects)
* [Topconfects in Bioconductor, development version](https://bioconductor.org/packages/devel/bioc/html/topconfects.html)
