
#' @import methods
#' @import utils
#' @import stats
#' @importFrom ggplot2
#'   aes_string geom_hline geom_point geom_segment geom_text
#'   geom_vline ggplot labs scale_x_continuous scale_y_continuous scale_size
#'   scale_color_discrete scale_color_manual guides guide_legend theme theme_bw
#'   coord_cartesian
#' @importFrom grid
#'   unit
#' @importFrom grDevices
#'   colorRampPalette
#' @importFrom assertthat
#'   assert_that
#'
NULL


